@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-from models import Block
+from .models import Block
 
 
 class BlockAdmin(admin.ModelAdmin):
